#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const figlet = require("figlet");
const optimist_1 = require("optimist");
const webdav_cli_server_1 = require("./webdav-cli.server");
const webdav_cli_constants_1 = require("./webdav-cli.constants");
console.log(chalk.green(figlet.textSync('webdav-cli', { horizontalLayout: 'full' })));
console.log(chalk.green(`Homepage: ${webdav_cli_constants_1.HOMEPAGE}\n`));
if (optimist_1.argv.help) {
    console.log([
        'usage: webdav-cli [options]',
        '',
        'options:',
        '  --path       Path to folder [process.cwd()]',
        '  --host       Host to use [127.0.0.1]',
        '  --port       Port to use [1900]',
        '  --digest     Enable digest authentication [basic]',
        '  --username   Username for basic/digest authentication [random]',
        '  --password   Password for basic/digest authentication [random]',
        '  --ssl        Enable https [false]',
        '  --sslKey     Path to ssl key file [self-signed]',
        '  --sslCert    Path to ssl cert file [self-signed]',
        '  --help       Print this list and exit',
        '  --version    Print the version and exit.',
        '  --rights     Comma separated values without spaces [all]', `
    'all', 'canCreate', 'canDelete', 'canMove', 'canRename', 
    'canAppend', 'canWrite', 'canRead', 'canSource', 
    'canGetMimeType', 'canGetSize', 'canListLocks', 
    'canSetLock', 'canRemoveLock', 'canGetAvailableLocks', 
    'canGetLock', 'canAddChild', 'canRemoveChild', 
    'canGetChildren', 'canSetProperty', 'canGetProperty', 
    'canGetProperties', 'canRemoveProperty', 'canGetCreationDate', 
    'canGetLastModifiedDate', 'canGetWebName', 'canGetType'`,
        '',
        'env:',
        '  WEBDAV_CLI_PATH, WEBDAV_CLI_HOST, WEBDAV_CLI_PORT,',
        '  WEBDAV_CLI_USERNAME, WEBDAV_CLI_PASSWORD, WEBDAV_CLI_DIGEST,',
        '  WEBDAV_CLI_SSL, WEBDAV_CLI_SSL_KEY, WEBDAV_CLI_SSL_CERT,',
        '  WEBDAV_CLI_RIGHTS, WEBDAV_CLI_DISABLE_AUTHENTICATION',
        '',
    ].join('\n'));
    process.exit();
}
if (optimist_1.argv.version) {
    console.log('Version: ' + require('../package.json').version, '\n');
    process.exit();
}
const argvRights = optimist_1.argv.rights && typeof optimist_1.argv.rights === 'string' ? optimist_1.argv.rights.split(',') : undefined;
const envRights = process.env.WEBDAV_CLI_RIGHTS ? process.env.WEBDAV_CLI_RIGHTS.split(',') : undefined;
const config = {
    path: optimist_1.argv.path || process.env.WEBDAV_CLI_PATH,
    host: optimist_1.argv.host || process.env.WEBDAV_CLI_HOST,
    port: optimist_1.argv.port || parseInt(process.env.WEBDAV_CLI_PORT),
    digest: optimist_1.argv.digest || Boolean(process.env.WEBDAV_CLI_DIGEST),
    username: optimist_1.argv.username || process.env.WEBDAV_CLI_USERNAME,
    password: optimist_1.argv.password || process.env.WEBDAV_CLI_PASSWORD,
    ssl: optimist_1.argv.ssl || Boolean(process.env.WEBDAV_CLI_SSL),
    sslKey: optimist_1.argv.sslKey || process.env.WEBDAV_CLI_SSL_KEY,
    sslCert: optimist_1.argv.sslCert || process.env.WEBDAV_CLI_SSL_CERT,
    disableAuthentication: optimist_1.argv.disableAuthentication || process.env.WEBDAV_CLI_DISABLE_AUTHENTICATION,
    rights: argvRights || envRights,
};
const run = async () => {
    const webdavCli = new webdav_cli_server_1.WebdavCli(config);
    const webdavCliServer = await webdavCli.start();
    webdavCliServer.on('log', (ctx, fs, path, log) => console.log(log));
};
run();
